@@ -232,6 +232,7 @@ class Representation:
         :param bar: Progress bar to update upon completion
         """
         cmd = [
+            "gm",
             "convert",
             "-size",
             f"{self.dim.width}x{self.dim.height}",
@@ -391,10 +392,15 @@ class BaseFile:
 
         for page in pages:
             try:
-                images.append(await asyncio.get_running_loop().run_in_executor(
+                image = await asyncio.get_running_loop().run_in_executor(
                     None,
                     Image.open,
-                    Path(self.pdf.parent, f"{page}.png"))
+                    Path(self.pdf.parent, f"{page}.png")
+                )
+                images.append(image)
+                await asyncio.get_running_loop().run_in_executor(
+                    None,
+                    image.load
                 )
             except IOError as e:
                 for image in images:
@@ -502,12 +508,11 @@ class Job:
         except QrexecError:
             await cancel_task(page_task)
             raise
-        else:
-            try:
-                self.bar.reset(total=pagenums)
-            except AttributeError:
-                self.bar.total = pagenums
-                self.bar.refresh()
+        try:
+            self.bar.reset(total=pagenums)
+        except AttributeError:
+            self.bar.total = pagenums
+            self.bar.refresh()
 
         self.pdf = Path(tmpdir, self.path.with_suffix(".trusted.pdf").name)
         self.base = BaseFile(self.path, pagenums, self.pdf)
@@ -555,8 +560,7 @@ class Job:
             await send(self.proc, data)
         except BrokenPipeError as e:
             raise QrexecError("Failed to send PDF") from e
-        else:
-            self.proc.stdin.write_eof()
+        self.proc.stdin.write_eof()
 
 
     async def _pagenums(self):
